@@ -136,10 +136,12 @@ class TestDrbNode(unittest.TestCase):
 
     def test_impl(self):
         self.assertFalse(self.node.has_impl(str))
-        self.assertTrue(self.node.has_impl(io.BytesIO))
-        self.assertTrue(self.node.has_impl(io.BufferedReader))
+        self.assertFalse(self.node.has_impl(io.BytesIO))
+        self.assertFalse(self.node.has_impl(io.BufferedReader))
+        self.assertTrue(self.node.has_impl(io.BufferedIOBase))
         self.assertEqual([io.BufferedIOBase], self.node.impl_capabilities())
-        self.assertEqual(b'', self.node.get_impl(io.BytesIO))
+        with self.assertRaises(DrbException):
+            self.node.get_impl(io.BytesIO)
         with self.assertRaises(DrbException):
             self.node.get_impl(int)
 
